==> jc-1.4.0.tar.gz: soot/tagkit/StdTagPrinter.c <==
// public class soot.tagkit.StdTagPrinter

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 78c9158d626879d1 soot_tagkit_StdTagPrinter
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag
// @dep_class ce07080b4f51cc0e soot_tagkit_TagPrinter

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_tagkit_StdTagPrinter
// @dep_header soot_tagkit_Tag
// @dep_header soot_tagkit_TagPrinter

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/tagkit/StdTagPrinter.h"
#include "soot/tagkit/Tag.h"
#include "soot/tagkit/TagPrinter.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_tagkit_StdTagPrinter$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_tagkit_StdTagPrinter$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_tagkit_StdTagPrinter$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_tagkit_StdTagPrinter$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_StdTagPrinter$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_StdTagPrinter$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_StdTagPrinter$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_StdTagPrinter, _init$52f4ad9f2989aeee);

void
_jc_soot_tagkit_StdTagPrinter$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_tagkit_StdTagPrinter$object *this)
{
	struct _jc_soot_tagkit_StdTagPrinter$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(35);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String print(java.lang.String, java.lang.String, soot.tagkit.Tag)
//

static _jc_linenum _jc_soot_tagkit_StdTagPrinter$linenum_table$print$ec2b3e4722a20d7e[];

static const unsigned char _jc_soot_tagkit_StdTagPrinter$param_ptypes$print$ec2b3e4722a20d7e[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_tagkit_StdTagPrinter$param_types$print$ec2b3e4722a20d7e[] = {
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type,
	&_jc_soot_tagkit_Tag$type
};

_jc_method _jc_soot_tagkit_StdTagPrinter$method_info$print$ec2b3e4722a20d7e = {
	.name=			"print",
	.signature=		"(Ljava/lang/String;Ljava/lang/String;Lsoot/tagkit/Tag;)Ljava/lang/String;",
	.class=			&_jc_soot_tagkit_StdTagPrinter$type,
	.param_types=		&_jc_soot_tagkit_StdTagPrinter$param_types$print$ec2b3e4722a20d7e,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_tagkit_StdTagPrinter$param_ptypes$print$ec2b3e4722a20d7e,
	.signature_hash=	_JC_JLONG(0xec2b3e4722a20d7e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_StdTagPrinter$method$print$ec2b3e4722a20d7e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_StdTagPrinter$vtable, soot_tagkit_StdTagPrinter.print$ec2b3e4722a20d7e) / sizeof(void *),
	.num_parameters=	3,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_StdTagPrinter$linenum_table$print$ec2b3e4722a20d7e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_StdTagPrinter, print$ec2b3e4722a20d7e);

_jc_java_lang_String$object *
_jc_soot_tagkit_StdTagPrinter$method$print$ec2b3e4722a20d7e(_jc_env *const env, _jc_soot_tagkit_StdTagPrinter$object *this, _jc_java_lang_String$object *param0, _jc_java_lang_String$object *param1, _jc_object *param2)
{
	struct _jc_soot_tagkit_StdTagPrinter$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_object *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	r3 = param2;
	_JC_LINE_NUMBER(41);				// 0
	r2 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, toString$7ea43b33b80a3070, r3);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_tagkit_StdTagPrinter$methods[] = {
	&_jc_soot_tagkit_StdTagPrinter$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_tagkit_StdTagPrinter$method_info$print$ec2b3e4722a20d7e
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_tagkit_StdTagPrinter$interfaces[] = {
	&_jc_soot_tagkit_TagPrinter$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_tagkit_StdTagPrinter$imethod_hash_bucket_126[] = {
	&_jc_soot_tagkit_StdTagPrinter$method_info$print$ec2b3e4722a20d7e,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_tagkit_StdTagPrinter$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[126]=	_jc_soot_tagkit_StdTagPrinter$imethod_hash_bucket_126
};

// Interface "quick" lookup hash table
static const void *_jc_soot_tagkit_StdTagPrinter$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[126]=	&_jc_soot_tagkit_StdTagPrinter$method$print$ec2b3e4722a20d7e
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_14[] = {
	&_jc_soot_tagkit_TagPrinter$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_81[] = {
	&_jc_soot_tagkit_StdTagPrinter$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_tagkit_StdTagPrinter$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[14]=	_jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_14,
	[81]=	_jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_81,
	[113]=	_jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_tagkit_StdTagPrinter$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
	{ "soot/tagkit/TagPrinter",	_JC_JLONG(0xce07080b4f51cc0e) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_tagkit_StdTagPrinter$vtype _jc_soot_tagkit_StdTagPrinter$type = {
    .type= {
	.name=			"soot/tagkit/StdTagPrinter",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_tagkit_StdTagPrinter$interfaces) / sizeof(*_jc_soot_tagkit_StdTagPrinter$interfaces),
	.interfaces=		_jc_soot_tagkit_StdTagPrinter$interfaces,
	.imethod_hash_table=	_jc_soot_tagkit_StdTagPrinter$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_tagkit_StdTagPrinter$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x78c9158d626879d1),
		.source_file=		"StdTagPrinter.java",
		.instance_size=		sizeof(_jc_soot_tagkit_StdTagPrinter$refs) + sizeof(_jc_soot_tagkit_StdTagPrinter$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_tagkit_StdTagPrinter$methods) / sizeof(*_jc_soot_tagkit_StdTagPrinter$methods),
		.methods=		_jc_soot_tagkit_StdTagPrinter$methods,
		.instanceof_hash_table=	_jc_soot_tagkit_StdTagPrinter$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_tagkit_StdTagPrinter$class_depends) / sizeof(*_jc_soot_tagkit_StdTagPrinter$class_depends),
		.class_depends=		_jc_soot_tagkit_StdTagPrinter$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_tagkit_StdTagPrinter= {
	    .print$ec2b3e4722a20d7e=
		&_jc_soot_tagkit_StdTagPrinter$method$print$ec2b3e4722a20d7e,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/tagkit/StdTagPrinter.c <==
// public class soot.tagkit.StdTagPrinter

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 78c9158d626879d1 soot_tagkit_StdTagPrinter
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag
// @dep_class ce07080b4f51cc0e soot_tagkit_TagPrinter

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_tagkit_StdTagPrinter
// @dep_header soot_tagkit_Tag
// @dep_header soot_tagkit_TagPrinter

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/tagkit/StdTagPrinter.h"
#include "soot/tagkit/Tag.h"
#include "soot/tagkit/TagPrinter.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_tagkit_StdTagPrinter$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_tagkit_StdTagPrinter$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_tagkit_StdTagPrinter$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_tagkit_StdTagPrinter$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_StdTagPrinter$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_StdTagPrinter$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_StdTagPrinter$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_StdTagPrinter, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_tagkit_StdTagPrinter$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_tagkit_StdTagPrinter$object *this)
{
	struct _jc_soot_tagkit_StdTagPrinter$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(35);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String print(java.lang.String, java.lang.String, soot.tagkit.Tag)
//

static _jc_linenum _jc_soot_tagkit_StdTagPrinter$linenum_table$print$ec2b3e4722a20d7e[];

static const unsigned char _jc_soot_tagkit_StdTagPrinter$param_ptypes$print$ec2b3e4722a20d7e[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_tagkit_StdTagPrinter$param_types$print$ec2b3e4722a20d7e[] = {
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type,
	&_jc_soot_tagkit_Tag$type
};

_jc_method _jc_soot_tagkit_StdTagPrinter$method_info$print$ec2b3e4722a20d7e = {
	.name=			"print",
	.signature=		"(Ljava/lang/String;Ljava/lang/String;Lsoot/tagkit/Tag;)Ljava/lang/String;",
	.class=			&_jc_soot_tagkit_StdTagPrinter$type,
	.param_types=		&_jc_soot_tagkit_StdTagPrinter$param_types$print$ec2b3e4722a20d7e,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_tagkit_StdTagPrinter$param_ptypes$print$ec2b3e4722a20d7e,
	.signature_hash=	_JC_JLONG(0xec2b3e4722a20d7e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_StdTagPrinter$method$print$ec2b3e4722a20d7e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_StdTagPrinter$vtable, soot_tagkit_StdTagPrinter.print$ec2b3e4722a20d7e) / sizeof(void *),
	.num_parameters=	3,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_StdTagPrinter$linenum_table$print$ec2b3e4722a20d7e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_StdTagPrinter, print$ec2b3e4722a20d7e);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_soot_tagkit_StdTagPrinter$method$print$ec2b3e4722a20d7e(_jc_env *const env, _jc_soot_tagkit_StdTagPrinter$object *this, _jc_java_lang_String$object *param0, _jc_java_lang_String$object *param1, _jc_object *param2)
{
	struct _jc_soot_tagkit_StdTagPrinter$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_object *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	r3 = param2;
	_JC_LINE_NUMBER(41);				// 0
	r2 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, toString$7ea43b33b80a3070, r3);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_tagkit_StdTagPrinter$methods[] = {
	&_jc_soot_tagkit_StdTagPrinter$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_tagkit_StdTagPrinter$method_info$print$ec2b3e4722a20d7e
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_tagkit_StdTagPrinter$interfaces[] = {
	&_jc_soot_tagkit_TagPrinter$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_tagkit_StdTagPrinter$imethod_hash_bucket_126[] = {
	&_jc_soot_tagkit_StdTagPrinter$method_info$print$ec2b3e4722a20d7e,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_tagkit_StdTagPrinter$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[126]=	_jc_soot_tagkit_StdTagPrinter$imethod_hash_bucket_126
};

// Interface "quick" lookup hash table
static const void *_jc_soot_tagkit_StdTagPrinter$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[126]=	&_jc_soot_tagkit_StdTagPrinter$method$print$ec2b3e4722a20d7e
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_14[] = {
	&_jc_soot_tagkit_TagPrinter$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_81[] = {
	&_jc_soot_tagkit_StdTagPrinter$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_tagkit_StdTagPrinter$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[14]=	_jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_14,
	[81]=	_jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_81,
	[101]=	_jc_soot_tagkit_StdTagPrinter$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_tagkit_StdTagPrinter$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
	{ "soot/tagkit/TagPrinter",	_JC_JLONG(0xce07080b4f51cc0e) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_tagkit_StdTagPrinter$vtype _jc_soot_tagkit_StdTagPrinter$type = {
    .type= {
	.name=			"soot/tagkit/StdTagPrinter",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_tagkit_StdTagPrinter$interfaces) / sizeof(*_jc_soot_tagkit_StdTagPrinter$interfaces),
	.interfaces=		_jc_soot_tagkit_StdTagPrinter$interfaces,
	.imethod_hash_table=	_jc_soot_tagkit_StdTagPrinter$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_tagkit_StdTagPrinter$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x78c9158d626879d1),
		.source_file=		"StdTagPrinter.java",
		.instance_size=		sizeof(_jc_soot_tagkit_StdTagPrinter$refs) + sizeof(_jc_soot_tagkit_StdTagPrinter$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_tagkit_StdTagPrinter$methods) / sizeof(*_jc_soot_tagkit_StdTagPrinter$methods),
		.methods=		_jc_soot_tagkit_StdTagPrinter$methods,
		.instanceof_hash_table=	_jc_soot_tagkit_StdTagPrinter$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_tagkit_StdTagPrinter$class_depends) / sizeof(*_jc_soot_tagkit_StdTagPrinter$class_depends),
		.class_depends=		_jc_soot_tagkit_StdTagPrinter$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_tagkit_StdTagPrinter= {
	    .print$ec2b3e4722a20d7e=
		&_jc_soot_tagkit_StdTagPrinter$method$print$ec2b3e4722a20d7e,
	},
    }
};
